@@ -57,7 +57,6 @@
  ***************************************************************************/
 
 #include <stdlib.h>
-#include <sidplayfp/sidendian.h>
 #include <vector>
 #include "WavFile.h"
 #include "WavFileDefs.h"
@@ -72,6 +71,53 @@
     typedef int openmode;
 #endif
 
+// Get the lo byte (8 bit) in a dword (32 bit)
+inline uint8_t endian_32lo8 (uint_least32_t dword)
+{
+    return (uint8_t) dword;
+}
+
+// Get the hi byte (8 bit) in a dword (32 bit)
+inline uint8_t endian_32hi8 (uint_least32_t dword)
+{
+    return (uint8_t) (dword >> 8);
+}
+
+// Get the hi word (16bit) in a dword (32 bit)
+inline uint_least16_t endian_32hi16 (uint_least32_t dword)
+{
+    return (uint_least16_t) (dword >> 16);
+}
+
+// Get the lo byte (8 bit) in a word (16 bit)
+inline uint8_t endian_16lo8 (uint_least16_t word)
+{
+    return (uint8_t) word;
+}
+
+// Set the hi byte (8 bit) in a word (16 bit)
+inline uint8_t endian_16hi8 (uint_least16_t word)
+{
+    return (uint8_t) (word >> 8);
+}
+
+// Write a little-endian 16-bit word to two bytes in memory.
+inline void endian_little16 (uint8_t ptr[2], uint_least16_t word)
+{
+    ptr[0] = endian_16lo8 (word);
+    ptr[1] = endian_16hi8 (word);
+}
+
+// Write a little-endian 32-bit word to four bytes in memory.
+inline void endian_little32 (uint8_t ptr[4], uint_least32_t dword)
+{
+    uint_least16_t word = 0;
+    ptr[0] = endian_32lo8  (dword);
+    ptr[1] = endian_32hi8  (dword);
+    word   = endian_32hi16 (dword);
+    ptr[2] = endian_16lo8  (word);
+    ptr[3] = endian_16hi8  (word);
+}
 
 const wavHeader WavFile::defaultWavHdr = {
     // ASCII keywords are hex-ified.
